import argparse
import pathlib

from . import Config, NamingScheme, standardize_java_text


def test_files(repo: pathlib.Path) -> list[pathlib.Path]:
    return list(repo.rglob('*.java'))


def standardize_in_file(
    path: pathlib.Path,
    inline: bool,
    config: Config,
):
    with open(path) as f:
        text = f.read()

    text_updated = standardize_java_text(
        text,
        config,
    )
    if text_updated == text:
        return

    if inline:
        with open(path, 'w') as f:
            f.write(text_updated)
    else:
        print(text_updated)


def argument_parser():
    argparser = argparse.ArgumentParser()
    argparser.add_argument('repo', type=pathlib.Path, help='Repository')
    argparser.add_argument('-i', action='store_true', help='Write to files')
    argparser.add_argument(
        '--javadoc',
        action='store_true',
        help='Generate Javadoc for tests',
    )
    argparser.add_argument(
        '--displayname',
        action='store_true',
        help='Generate DisplayName for tests',
    )
    argparser.add_argument(
        '--only-javadoc',
        action='store_true',
        help='Only change tests with an existing Javadoc',
    )
    argparser.add_argument(
        '--only-displayname',
        action='store_true',
        help='Only change test with an existing DisplayName',
    )
    argparser.add_argument(
        '--naming',
        type=NamingScheme,
        choices=list(NamingScheme),
        default=NamingScheme.FROM_DESC,
        help='How to derive the name of the test method',
    )
    return argparser


def main():
    args = argument_parser().parse_args()

    config = Config(
        with_javadoc=args.javadoc,
        with_display_name=args.displayname,
        only_for_javadoc=args.only_javadoc,
        only_for_display_name=args.only_displayname,
        naming_scheme=args.naming,
    )

    for path in test_files(args.repo):
        standardize_in_file(
            path,
            inline=args.i,
            config=config,
        )


if __name__ == '__main__':
    main()
